@@ -1,4 +1,7 @@
 package MooseX::Privacy::Trait::Role;
+BEGIN {
+  $MooseX::Privacy::Trait::Role::VERSION = '0.02';
+}
 
 use MooseX::Role::Parameterized;
 
@@ -20,25 +23,28 @@ role {
 };
 
 1;
+
 __END__
+=pod
 
 =head1 NAME
 
 MooseX::Privacy::Trait::Role
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-=head1 METHODS
+version 0.02
 
 =head1 AUTHOR
 
-franck cuny E<lt>franck@lumberjaph.netE<gt>
+  franck cuny <franck@lumberjaph.net>
 
-=head1 SEE ALSO
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+This software is copyright (c) 2010 by franck cuny.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
